{% for message in messages %}
{% if message.tags == 'error' %}
<div class="alert alert-danger" role="alert">
    {{ message }}
</div>
{% else %}
<div class="alert alert-{{ message.tags }}" role="alert">
    {{ message }}
</div>
{% endif %}
{% endfor %}